#! /usr/bin/perl
#******************************************************************************
# Arianna Bisazza @ FBK-irst. April 2012
#******************************************************************************

use strict;

use open ':utf8';
binmode STDIN, ':utf8';
binmode STDOUT, ':utf8';
use Getopt::Long;

my $usage = "
-----
applyWordMapping.pl --map=MAPFILE (--field=N) (--no-split) < corpus > corpus.mapped
-----
# Given a TreeTagger processed corpus and a corpus dictionary (with possible case/tokenization differences)
#
# Required:
# --map=MAPFILE : File containing the word-class map, tab-separated (may have multiple fields)
#
# Options:
# --field=N     : Map words to the Nth field of the map-file
# --no-split    : Treats each corpus line as a single token
#
";

my $mapfile= '';
my $field_nb = '1';
my $no_split = '';
my $debug = '';

GetOptions ('map=s' => \$mapfile,
            'field=i'  => \$field_nb,
	    'no-split' => \$no_split,
            'debug' => \$debug);

############################

if($mapfile eq "") { die "$usage\n\nPlease specify a mapfile!\n"; }
open(MAP, $mapfile) or die "Cannot open mapfile $mapfile : ($!)\n";

# load mapfile
my %map;
while (my $line = <MAP>) {
	chomp $line;
	my @fields= split('\t', $line);
	$map{$fields[0]}=$fields[$field_nb];
}


while (my $line = <STDIN>) {
	chomp $line;
	my @tokens;
	if($no_split) { push (@tokens, $line);}
	else { @tokens= split(' ', $line);}

	$line="";
	foreach my $token (@tokens) {
		if(defined $map{$token}) { $token=$map{$token}; }
		$line.="$token ";
	}
	$line =~ s/\ ?$//;
	print $line, "\n";
}
