set -x

#******************************************************************************
# Arianna Bisazza @ FBK-irst. April 2012
#******************************************************************************
# Wrapper script for hybrid LM training. See README file in this folder.

#################
# Dependencies -- set the following paths
IRSTLM=/path-to-irstlm
# NOTE: IRSTLM should be version 5.70.04 or later
#############
# Training corpus
corpus=example/minitrain.en.tok
#corpus=example/minitrain.fr.tok.lc
#############
# Training corpus suffix -- set here
#suffix=hyb20
suffix=hybLL20
# NOTE: verify that $corpus.$suffix.snt exists!
#############
# Test corpus
test=example/minitest.en.tok
#test=example/minitest.fr.tok.lc
#############
# N-gram order
N=5
#############
# Smoothing technique
smooth="wb"
#############
# Prune Singletons
PS="no";  psSuff=""
#PS="yes"  psSuff=".ps"
#############

###### STEPS TO EXECUTE #######
DO_TRAIN=1
DO_TEXT_LM=0
DO_TEST=1
###############################
wdir=`pwd`

## INPUT FILES
traincorpus=$corpus.$suffix.snt
mapfile=$corpus.word-tag-map.$suffix
## OUTPUT FILES
outdir=`dirname $traincorpus`
lmfile=$traincorpus.${N}g$psSuff.$smooth
config_file=$lmfile.cfg-lmclass
eval_file=$lmfile.EVAL


if [ $DO_TRAIN == 1 ]; then
    date; echo;
    set -x
    $IRSTLM/bin/tlm \
	-ps=${PS} -dub=10000000 \
	-n=${N} -lm=$smooth \
	-tr=$traincorpus \
	-obin=$lmfile.blm
    date; echo;

	# prepare irstlm config file
	echo "LMCLASS $N" >  $config_file
	echo $lmfile.blm >> $config_file
	echo $mapfile    >> $config_file
fi

if [ $DO_TEXT_LM == 1 ]; then
    $IRSTLM/bin/compile-lm --text=yes $lmfile.blm $lmfile.lm 
fi

if [ $DO_TEST == 1 ]; then
    sh $IRSTLM/scripts/add-start-end.sh <  $test >  $test.snt
    $IRSTLM/bin/compile-lm --eval $test.snt  $config_file > $eval_file
fi
